SystemOrganization addCategory: #FlowRiak!
SystemOrganization addCategory: #'FlowRiak-Tests'!
SystemOrganization addCategory: #'FlowRiak-Models'!

Object subclass: #FlowRiak
	instanceVariableNames: 'sessions databases'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FlowRiak'!

FlowRiak class
	instanceVariableNames: 'instance configuration'!

!FlowRiak commentStamp: 'sebastiansastre 4/25/2012 15:21' prior: 0!
FlowRiak is flow's API to use Riak

It has sessions and general questions about proceeding with Riak's usage to store flow's aggregates
!

FlowRiak class
	instanceVariableNames: 'instance configuration'!

!FlowRiak class methodsFor: 'accessing' stamp: 'sebastiansastre 4/24/2012 11:12'!
configuration 

	^ configuration ifNil:[self initializeConfiguration]! !

!FlowRiak class methodsFor: 'initialization' stamp: 'sebastiansastre 4/24/2012 11:15'!
initializeConfiguration

	^ configuration := self makeConfiguration ! !

!FlowRiak class methodsFor: 'initialization' stamp: 'sebastiansastre 4/24/2012 10:47'!
initializeInstance

	^ instance := self new! !

!FlowRiak class methodsFor: 'accessing' stamp: 'sebastiansastre 4/24/2012 10:47'!
instance

	^ instance ifNil:[self initializeInstance]! !

!FlowRiak class methodsFor: 'actions' stamp: 'sebastiansastre 5/18/2012 10:09'!
makeConfiguration

	^ Dictionary new
		at: #riak put: (Dictionary new
							at: #host put: 'localhost';
							at: #port put: 8098;
							at: #path put: '/';
							yourself);
		at: #default put: (Dictionary new
							at: #host put: 'localhost';
							at: #port put: 8098;
							at: #path put: '/';
							yourself);
		at: #flowing put: (Dictionary new
							at: #host put: 'localhost';
							at: #port put: 8098;
							at: #path put: '/';
							yourself);
		at: #test put: (Dictionary new
							at: #host put: 'localhost';
							at: #port put: 8098;
							at: #path put: '/';
							yourself);
		yourself ! !

!FlowRiak class methodsFor: 'actions' stamp: 'sebastiansastre 5/16/2012 23:08'!
reset

	configuration := nil.
	
	instance ifNotNil:[
		instance reset.
		instance := nil]! !

!FlowRiak methodsFor: 'actions' stamp: 'sebastiansastre 5/16/2012 23:01'!
createDatabase: aDatabaseName
	"Creates a database named aDatabaseName in the Riak repo"
	
	| riak db |
	
	riak := self sessionAt: #riak.
	
	riak do:[
		(self hasDatabase: aDatabaseName) ifTrue:[
			self error: 'Cannot create ', aDatabaseName, ' because there is one already with that name'].
	
		db := FlowRiakDatabase new
				name: aDatabaseName;
				save].
	
	self resetDatabases.
	
	^ db! !

!FlowRiak methodsFor: 'accessing' stamp: 'sebastiansastre 4/25/2012 20:05'!
databaseAt: aDatabaseName 

	^ self databases detect:[:e| e name = aDatabaseName]! !

!FlowRiak methodsFor: 'accessing' stamp: 'sebastiansastre 4/24/2012 11:41'!
databases

	^ databases ifNil:[self initializeDatabases]! !

!FlowRiak methodsFor: 'actions' stamp: 'sebastiansastre 5/16/2012 23:02'!
dropDatabase: aDatabaseName
	"Drops the database (or silently do nothing if there isn't one)."
	
	| db riak |
	
	riak := self sessionAt: #riak.
	riak do:[
		(self hasDatabase: aDatabaseName) ifFalse:[^nil].
	
		db := self databaseAt: aDatabaseName.
		self databases remove: db ifAbsent:[nil].

		^ db destroy]! !

!FlowRiak methodsFor: 'accessing' stamp: 'sebastiansastre 5/7/2012 00:01'!
getDatabases 

	^ FlowRiakDatabase findAll asOrderedCollection do:[:db|
		self observeDatabase: db]; yourself ! !

!FlowRiak methodsFor: 'testing' stamp: 'sebastiansastre 4/25/2012 15:23'!
hasDatabase: aDatabaseName

	^ self databases anySatisfy:[:e|
		e name = aDatabaseName]! !

!FlowRiak methodsFor: 'initialization' stamp: 'sebastiansastre 4/24/2012 11:42'!
initializeDatabases 

	^ databases := self getDatabases ! !

!FlowRiak methodsFor: 'initialization' stamp: 'sebastiansastre 4/24/2012 10:50'!
initializeSessions

	^ sessions := Dictionary new! !

!FlowRiak methodsFor: 'actions' stamp: 'sebastiansastre 5/16/2012 23:03'!
makeSessionFor: aKey

	^ self makeSessionFor: aKey on: aKey asString! !

!FlowRiak methodsFor: 'actions' stamp: 'sebastiansastre 5/16/2012 23:05'!
makeSessionFor: aKey on: aDatabaseName

	| spec |
	
	spec := self class configuration 
		at: aKey
		ifAbsent:[self error: 'There is no configuration to make this session'].
		
	^ FlowRiakSession 
		on: aDatabaseName 
		on: (RiakProtocol new
			host: (spec at: #host);
			port: (spec at: #port);
			riakPath: (spec at: #path);
			yourself)! !

!FlowRiak methodsFor: 'actions' stamp: 'sebastiansastre 5/7/2012 00:02'!
observeDatabase: aDatabase

	aDatabase when: #onDestroy: send: #onDestroyDatabase: to: self! !

!FlowRiak methodsFor: 'reactions' stamp: 'sebastiansastre 5/7/2012 00:02'!
onDestroyDatabase: aDatabase

	self resetDatabases! !

!FlowRiak methodsFor: 'actions' stamp: 'sebastiansastre 4/25/2012 18:43'!
reset 

	self resetDatabases.

	sessions ifNotNil:[
		sessions do:[:e| e reset].
		sessions := nil].
	! !

!FlowRiak methodsFor: 'actions' stamp: 'sebastiansastre 4/25/2012 18:43'!
resetDatabases

	databases := nil! !

!FlowRiak methodsFor: 'accessing' stamp: 'sebastiansastre 4/25/2012 15:46'!
session

	^ FlowRiakSessionContext value ifNil:[
		self error: 'No Riak session is active']
	! !

!FlowRiak methodsFor: 'accessing' stamp: 'sebastiansastre 4/24/2012 11:07'!
sessionAt: aKey

	^ self sessions 
		at: aKey
		ifAbsentPut:[self makeSessionFor: aKey]! !

!FlowRiak methodsFor: 'accessing' stamp: 'sebastiansastre 5/16/2012 22:11'!
sessionAt: aKey on: aDatabaseName 

	^ self sessions 
		at: aKey
		ifAbsentPut:[self makeSessionFor: aKey on: aDatabaseName]! !

!FlowRiak methodsFor: 'accessing' stamp: 'sebastiansastre 4/24/2012 10:49'!
sessions

	^ sessions ifNil:[self initializeSessions]! !

RiakSession subclass: #FlowRiakSession
	instanceVariableNames: 'database buckets'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FlowRiak'!

!FlowRiakSession commentStamp: 'sebastiansastre 4/25/2012 16:20' prior: 0!
FlowRiakSession is a RiakSession that chaches stuff.

The buckets are cached because the FlowRiakModels are probably going to ask very frequently for their buckets so creating them on the fly all the time might not be that clever.


		!

!FlowRiakSession class methodsFor: 'instance creation' stamp: 'sebastiansastre 5/16/2012 23:05'!
on: aDatabaseName on: aProtocol

	^self new 
		database: aDatabaseName;
		protocol: aProtocol;
		yourself! !

!FlowRiakSession methodsFor: 'accessing' stamp: 'sebastiansastre 4/25/2012 16:15'!
bucketNamed: aString

	^ self buckets 
		at: aString
		ifAbsentPut:[self makeBucketNamed: aString]! !

!FlowRiakSession methodsFor: 'accessing' stamp: 'sebastiansastre 4/25/2012 16:13'!
buckets
	^ buckets ifNil:[self initializeBuckets]! !

!FlowRiakSession methodsFor: 'accessing' stamp: 'sebastiansastre 4/25/2012 16:13'!
buckets: anObject
	buckets := anObject! !

!FlowRiakSession methodsFor: 'accessing' stamp: 'sebastiansastre 5/16/2012 23:04'!
database
	^ database! !

!FlowRiakSession methodsFor: 'accessing' stamp: 'sebastiansastre 5/16/2012 23:04'!
database: anObject
	database := anObject! !

!FlowRiakSession methodsFor: 'actions' stamp: 'sebastiansastre 5/16/2012 23:05'!
do: aBlock

	FlowRiakSessionContext
		value: self
		during: [
			FlowRiakDatabaseContext
				value: database
				during: [^ aBlock value]]! !

!FlowRiakSession methodsFor: 'initialization' stamp: 'sebastiansastre 4/25/2012 20:02'!
initializeBuckets
	^ buckets := Dictionary new! !

!FlowRiakSession methodsFor: 'actions' stamp: 'sebastiansastre 4/25/2012 16:15'!
makeBucketNamed: aString

	^ RiakBucket name: aString session: self! !

!FlowRiakSession methodsFor: 'actions' stamp: 'sebastiansastre 5/18/2012 10:10'!
printOn: aStream

	super printOn: aStream.
	
	aStream nextPutAll: '(',database asString,')'! !

!FlowRiakSession methodsFor: 'actions' stamp: 'sebastiansastre 4/25/2012 16:17'!
reset

	protocol := nil.
	buckets := nil.! !

DynamicVariable subclass: #FlowRiakDatabaseContext
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FlowRiak'!

DynamicVariable subclass: #FlowRiakSessionContext
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FlowRiak'!

OrderedJsonObject subclass: #FlowRiakModelReference
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FlowRiak'!

!FlowRiakModelReference class methodsFor: 'actions' stamp: 'sebastiansastre 5/16/2012 13:47'!
for: aRiakModel

	^ self new
		initializeOn: aRiakModel;
		yourself ! !

!FlowRiakModelReference methodsFor: 'initialization' stamp: 'sebastiansastre 5/16/2012 23:14'!
initializeOn: aRiakModel

	self key: aRiakModel id.
	self database: aRiakModel class databaseName.
	self type: aRiakModel class name.
	
	! !

!FlowRiakModelReference methodsFor: 'accessing' stamp: 'sebastiansastre 5/17/2012 15:17'!
unreferenced

	self halt.! !

TestCase subclass: #FlowRiakTestCase
	instanceVariableNames: 'session'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FlowRiak-Tests'!

FlowRiakTestCase subclass: #FlowRiakBasicTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FlowRiak-Tests'!

!FlowRiakBasicTests methodsFor: 'actions' stamp: 'sebastiansastre 4/28/2012 00:26'!
testCreateAndDropDatabase

	session do:[
		(Flow riak hasDatabase: 'objects') ifTrue:[
			(Flow riak databaseAt: 'objects') destroy]].
	 
	session do:[ 		
		Flow riak createDatabase: 'objects'].
		
	session do:[ 
		self shouldnt: [Flow riak databaseAt: 'objects'] raise: NotFound.
		self assert: (Flow riak databaseAt: 'objects') notNil.
		self assert: (Flow riak databaseAt: 'objects') name = 'objects'].

	session do:[ 
		self shouldnt: [Flow riak databaseAt: 'objects'] raise: NotFound.
		self assert: (Flow riak databaseAt: 'objects') name = 'objects'.
		Flow riak dropDatabase: 'objects'].

	session do:[ 
		self should: [Flow riak databaseAt: 'objects'] raise: NotFound].
	! !

!FlowRiakBasicTests methodsFor: 'actions' stamp: 'sebastiansastre 4/27/2012 23:47'!
testDelete! !

!FlowRiakBasicTests methodsFor: 'actions' stamp: 'sebastiansastre 4/27/2012 23:47'!
testDestroy! !

!FlowRiakBasicTests methodsFor: 'actions' stamp: 'sebastiansastre 4/27/2012 23:49'!
testFindAll! !

!FlowRiakBasicTests methodsFor: 'actions' stamp: 'sebastiansastre 4/27/2012 23:49'!
testFindAllOnDatabase! !

!FlowRiakBasicTests methodsFor: 'actions' stamp: 'sebastiansastre 4/27/2012 23:47'!
testSave! !

!FlowRiakTestCase methodsFor: 'actions' stamp: 'sebastiansastre 4/27/2012 23:46'!
newSession

	^ FlowRiakSession default! !

!FlowRiakTestCase methodsFor: 'actions' stamp: 'sebastiansastre 4/27/2012 23:45'!
setUp

	session := self newSession! !

!FlowRiakTestCase methodsFor: 'actions' stamp: 'sebastiansastre 4/27/2012 23:45'!
tearDown 

	session reset.
	session := nil! !

FlowModel subclass: #FlowRiakModel
	instanceVariableNames: 'riak'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FlowRiak-Models'!

!FlowRiakModel commentStamp: 'sebastiansastre 4/24/2012 12:01' prior: 0!
These kind of models are meant to store replicas of the instances in a Riak bucket.

#key is reserved to be used as a Riak meaningful key
#value ditto

!

FlowRiakModel subclass: #FlowRiakDatabase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FlowRiak-Models'!

!FlowRiakDatabase commentStamp: 'sebastiansastre 4/24/2012 13:35' prior: 0!
FlowRiakDatabase

These aggregates are one per database in the Riak repository.
The idea is that applications can use this to query which "databases" are being managed by the app in the whoe riak repo.

!

!FlowRiakDatabase methodsFor: 'actions' stamp: 'sebastiansastre 4/25/2012 15:16'!
printOn: aStream

	super printOn: aStream.
	
	aStream nextPutAll: '(',self name asString,')'! !

!FlowRiakModel class methodsFor: 'actions' stamp: 'sebastiansastre 7/26/2012 13:17'!
allFor: aRequest

	^ self answerJSONFor: self findAll
	
	! !

!FlowRiakModel class methodsFor: 'actions' stamp: 'sebastiansastre 5/16/2012 22:24'!
allKeys

	^ self allKeysOn: self databaseName 	! !

!FlowRiakModel class methodsFor: 'actions' stamp: 'sebastiansastre 7/26/2012 13:08'!
allKeysOn: aDatabaseName
	"Expensive!!"
	
	^ self bucket keysIndexed: 'database' value: aDatabaseName

	! !

!FlowRiakModel class methodsFor: 'accessing' stamp: 'sebastiansastre 4/25/2012 15:55'!
bucket 

	^ self session bucketNamed: self bucketName! !

!FlowRiakModel class methodsFor: 'accessing' stamp: 'sebastiansastre 4/24/2012 13:29'!
bucketName

	^ self name asString! !

!FlowRiakModel class methodsFor: 'actions' stamp: 'sebastiansastre 7/26/2012 13:27'!
createFor: aRequest

	| sent |

	[sent := self fromJson: aRequest contents keys first.
	sent initialize] on: Error do:[:x|
		^ ZnResponse badRequest: aRequest].

	^ self answerJSONFor: sent save! !

!FlowRiakModel class methodsFor: 'actions' stamp: 'sebastiansastre 7/26/2012 13:08'!
createOn: aDatabaseName

	^ self answerJSONFor: self new save! !

!FlowRiakModel class methodsFor: 'accessing' stamp: 'sebastiansastre 5/16/2012 22:16'!
databaseName

	^ FlowRiakDatabaseContext value ifNil:[
		self error: 'No Flow Riak database was specified']
	! !

!FlowRiakModel class methodsFor: 'actions' stamp: 'sebastiansastre 5/16/2012 22:45'!
find: aBlock

	^ self findAll detect: aBlock! !

!FlowRiakModel class methodsFor: 'actions' stamp: 'sebastiansastre 5/16/2012 22:45'!
find: aBlock ifNone: anotherBlock

	^ self findAll detect: aBlock ifNone: anotherBlock! !

!FlowRiakModel class methodsFor: 'actions' stamp: 'sebastiansastre 5/16/2012 22:24'!
findAll

	^ self findAllOn: self databaseName ! !

!FlowRiakModel class methodsFor: 'actions' stamp: 'sebastiansastre 7/26/2012 13:18'!
findAllFor: aRequest 

	^ self answerJSONFor: self findAll	! !

!FlowRiakModel class methodsFor: 'actions' stamp: 'sebastiansastre 7/26/2012 13:08'!
findAllOn: aDatabaseName

	^ (self allKeysOn: aDatabaseName) collect:[:k| 
		self findAt: k]
	! !

!FlowRiakModel class methodsFor: 'actions' stamp: 'sebastiansastre 5/15/2012 20:03'!
findAt: aKey

	^ [self fromRiak: (self bucket at: aKey)]
		on: RiakNotFoundError
		do:[:x| nil]! !

!FlowRiakModel class methodsFor: 'actions' stamp: 'sebastiansastre 7/10/2012 20:02'!
findIn: anIndexName at: anIndexedValue

	^ (self bucket keysIndexed: 'number' value: anIndexedValue) collect:[:e|
		self findAt: e]
	! !

!FlowRiakModel class methodsFor: 'actions' stamp: 'sebastiansastre 7/16/2012 22:03'!
first

	^ [:all|
		all isEmpty
			ifTrue:[nil]
			ifFalse:[all first]] value: self findAll! !

!FlowRiakModel class methodsFor: 'accessing' stamp: 'sebastiansastre 5/16/2012 22:32'!
fromReference: aRiakModelReference
	"Answers a new instance of this model using the
	data found with aRiakModelReference (or nil)"

	"Note: this is flexible, meaning that references does not forces you to work inside one database,
	you can have a model in one database with a reference to another mode model in
	another database."
	^ self findAt: aRiakModelReference key,'-',aRiakModelReference database! !

!FlowRiakModel class methodsFor: 'actions' stamp: 'sebastiansastre 5/16/2012 18:13'!
fromRiak: aRiakObject
	"Answer the instance of this kind of model based on aRiakObject"

	^ self new 
		initializeOn: aRiakObject;
		yourself ! !

!FlowRiakModel class methodsFor: 'actions' stamp: 'sebastiansastre 5/16/2012 22:33'!
reIndex
	"Expensive!!
	Rebuild the indexes of this models"
	
	self reIndexOn: self databaseName ! !

!FlowRiakModel class methodsFor: 'actions' stamp: 'sebastiansastre 5/16/2012 22:06'!
reIndexOn: aDatabaseName
	"Expensive!!
	Rebuild the indexes of this models"
	
	(self findAllOn: aDatabaseName) do:[:each|
		each initializeRiak; save]! !

!FlowRiakModel class methodsFor: 'actions' stamp: 'sebastiansastre 7/26/2012 13:11'!
readFor: aRequest

	| id |

	[id := aRequest uri queryAt: 'id'] on: Error do:[:x| 
		^ ZnResponse badRequest: aRequest].

	^ self answerJSONFor: (self findAt: id)! !

!FlowRiakModel class methodsFor: 'actions' stamp: 'sebastiansastre 7/26/2012 13:11'!
saveFor: aRequest

	| sent |

	[sent := self fromJson: aRequest contents keys first] on: Error do:[:x| 
		^ ZnResponse badRequest: aRequest].

	^ self answerJSONFor: sent save! !

!FlowRiakModel class methodsFor: 'accessing' stamp: 'sebastiansastre 4/25/2012 15:46'!
session

	^ FlowRiakSessionContext value ifNil:[
		self error: 'No Riak session is active']
	! !

!FlowRiakModel methodsFor: 'accessing' stamp: 'sebastiansastre 7/26/2012 16:47'!
asJsonString
	"Answers the JSON representation of this aggregate.
	Note: sub models are going to be referenced in a sub-model-holder
	so they can be later retrieved on demand"

	| copy |
	
	copy := data copy.
	
	data keysAndValuesDo:[:k :v| 
		(v isKindOf: FlowRiakModelReference) ifTrue:[
			copy at: k put: v unreferenced].
		
		"If the value is a submodel then we add  the class name on it."
		"(v class inheritsFrom: FlowRiakModel) ifTrue:[
			copy at: k put: v asJsonString]"].

	^ copy asJsonString! !

!FlowRiakModel methodsFor: 'accessing' stamp: 'sebastiansastre 5/17/2012 11:30'!
asJsonStringWithReferences
	"Answers the JSON representation of this aggregate.
	Note: sub models are going to be referenced in a sub-model-holder
	so they can be later retrieved on demand"
	
	| copy |
	
	copy := data copy.

	data keysAndValuesDo:[:k :v| 
		(v isKindOf: FlowRiakModel) ifTrue:[
			copy at: k put: v asReference]].
	
	^ copy asJsonString 
! !

!FlowRiakModel methodsFor: 'actions' stamp: 'sebastiansastre 5/16/2012 13:57'!
asReference

	^ FlowRiakModelReference for: self! !

!FlowRiakModel methodsFor: 'actions' stamp: 'sebastiansastre 5/6/2012 23:59'!
delete

	self onAboutToDelete.
	
	self isDeleted: true.
	self setData.
	self riak store! !

!FlowRiakModel methodsFor: 'actions' stamp: 'sebastiansastre 5/6/2012 23:58'!
destroy
	
	self onAboutToDestroy.
	
	self riak remove! !

!FlowRiakModel methodsFor: 'actions' stamp: 'sebastiansastre 5/18/2012 10:07'!
fresh

	^ self class findAt: self id! !

!FlowRiakModel methodsFor: 'initialization' stamp: 'sebastiansastre 5/16/2012 22:36'!
initializeOn: aRiakObject

	riak := aRiakObject.
	data := OrderedJson readFrom: riak data readStream.
	! !

!FlowRiakModel methodsFor: 'initialization' stamp: 'sebastiansastre 4/25/2012 19:40'!
initializeRiak
	^ riak := self makeRiak! !

!FlowRiakModel methodsFor: 'accessing' stamp: 'sebastiansastre 5/18/2012 10:07'!
key

	^ self id
	! !

!FlowRiakModel methodsFor: 'actions' stamp: 'sebastiansastre 5/16/2012 23:11'!
makeIndexes

	^ OrderedCollection new 
		add: (RiakIndex key: 'database' value: self class databaseName);
		yourself ! !

!FlowRiakModel methodsFor: 'actions' stamp: 'sebastiansastre 5/18/2012 10:54'!
makeRiak 

	^ (RiakObject on: self class bucket)
		key: self id;
		yourself! !

!FlowRiakModel methodsFor: 'reactions' stamp: 'sebastiansastre 5/16/2012 11:55'!
onAboutToDelete

	self triggerEvent: #aboutToDelete: with: self! !

!FlowRiakModel methodsFor: 'reactions' stamp: 'sebastiansastre 5/16/2012 11:55'!
onAboutToDestroy
	
	self triggerEvent: #aboutToDestroy: with: self! !

!FlowRiakModel methodsFor: 'reactions' stamp: 'sebastiansastre 5/18/2012 10:55'!
onAboutToSave

	self setData.
	self updateIndexes.
	
	self triggerEvent: #aboutToSave: with: self! !

!FlowRiakModel methodsFor: 'accessing' stamp: 'sebastiansastre 4/25/2012 19:40'!
riak
	^ riak ifNil:[self initializeRiak]! !

!FlowRiakModel methodsFor: 'accessing' stamp: 'sebastiansastre 4/25/2012 16:06'!
riak: anObject
	riak := anObject! !

!FlowRiakModel methodsFor: 'actions' stamp: 'sebastiansastre 5/18/2012 10:54'!
save

	self onAboutToSave.
	
	self riak store.! !

!FlowRiakModel methodsFor: 'accessing' stamp: 'sebastiansastre 4/25/2012 15:46'!
session

	^ self class session! !

!FlowRiakModel methodsFor: 'actions' stamp: 'sebastiansastre 5/18/2012 10:07'!
setData
	"Put a fresh jsonserialization of this model in the riak object"
	
	self riak 
		key: self id;
		data: self asJsonString;
		yourself ! !

!FlowRiakModel methodsFor: 'actions' stamp: 'sebastiansastre 5/18/2012 10:55'!
updateIndexes

	self riak indexes: self makeIndexes! !

FlowRiakModel subclass: #FlowRiakToDo
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FlowRiak-Models'!

FlowRiakModel subclass: #FlowRiakToDoList
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FlowRiak-Models'!
